@@ -30,9 +30,9 @@ extensions = [
 ]
 
 # openstackdocstheme options
-repository_name = 'openstack/openstacksdk'
-bug_project = '972'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/openstacksdk'
+openstackdocs_pdf_link = True
+openstackdocs_use_storyboard = True
 html_theme = 'openstackdocs'
 
 # TODO(shade) Set this to true once the build-openstack-sphinx-docs job is
@@ -64,7 +64,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 autodoc_member_order = "bysource"
 
